@@ -43,7 +43,7 @@ class Storage(driver.Base):
     def get_json(self, path):
         logger.info("get_json path:%s" % path)
         try:
-            return json.loads(self.get_unicode(path))
+            return json.loads(self.get_unicode("/tmp/registry/"+path))
         except Exception as e:
             logger.error("get_json error:%s" % e)
             return []
